@@ -24,13 +24,13 @@ __PACKAGE__->mk_accessors(qw(name version factories commands message capabilitie
 
 use Net::DRI::Exception;
 
-our $VERSION=do { my @r=(q$Revision: 1.4 $=~/\d+/g); sprintf("%d"."%02d" x $#r, @r); };
+our $VERSION=do { my @r=(q$Revision: 1.5 $=~/\d+/g); sprintf("%d".".%02d" x $#r, @r); };
 
 =pod
 
 =head1 NAME
 
-Net::DRI::Protocol
+Net::DRI::Protocol - Superclass of all Net::DRI Protocols
 
 =head1 DESCRIPTION
 
@@ -151,7 +151,6 @@ sub action
  ## Create a new message from scratch and loop through all functions registered for given action & type
  my $f=$self->factories();
  my $msg=$f->{message}->new();
- ## TO FIX: verify $msg is defined
  $msg->version($self->version());
  $self->message($msg); ## store it for later use (in loop below)
  
@@ -172,7 +171,7 @@ sub reaction
  my $h=$self->_load_commands($otype,$oaction);
  my $f=$self->factories();
  my $msg=$f->{message}->new();
- $msg->parse($dr); ## TO FIX ? (see above)
+ $msg->parse($dr);
  Net::DRI::Exception->die(0,'protocol',1,'Unsuccessfull parse') unless ($msg && ref($msg) && $msg->isa('Net::DRI::Protocol::Message'));
 
  $msg->version($self->version());
